@@ -11,7 +11,7 @@
 #               4) Jaroslav Stepanek via rt.cpan.org
 #               5) Nick Livchits private communication
 #               6) Sreerag Raghavan private communication (SM-C200)
-#               IB) Iliah Borg private communcation (LibRaw)
+#               IB) Iliah Borg private communication (LibRaw)
 #               NJ) Niels Kristian Bech Jensen private communication
 #------------------------------------------------------------------------------
 
@@ -22,7 +22,7 @@ use vars qw($VERSION %samsungLensTypes);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.47';
+$VERSION = '1.48';
 
 sub WriteSTMN($$$);
 sub ProcessINFO($$$);
@@ -960,6 +960,8 @@ my %formatMinMax = (
    # 0x08e0-name - seen 'Panorama_Shot_Info'
    # 0x08e0 - string, seen 'PanoramaShot'
    # 0x08e1-name - seen 'Motion_Panorama_Info'
+   # 0x0910-name - seen 'Front_Cam_Selfie_Info'
+   # 0x0910 - string, seen 'Front_Cam_Selfie_Info'
    # 0x09e0-name - seen 'Burst_Shot_Info'
    # 0x09e0 - string, seen '489489125'
    # 0x0a01-name - seen 'Image_UTC_Data'
@@ -974,7 +976,7 @@ my %formatMinMax = (
     '0x0a30-name' => 'EmbeddedVideoType', # ("MotionPhoto_Data")
     '0x0a30' => { Name => 'EmbeddedVideoFile', Groups => { 2 => 'Video' }, Binary => 1 }, #forum7161
    # 0x0aa1-name - seen 'MCC_Data'
-   # 0x0aa1 - seen '234','222'
+   # 0x0aa1 - seen '234','222','429'
    # 0x0ab0-name - seen 'DualShot_Meta_Info'
     '0x0ab1-name' => 'DepthMapName', # seen 'DualShot_DepthMap_1' (SM-N950U)
     '0x0ab1' => { Name => 'DepthMapData', Binary => 1 },
@@ -1001,35 +1003,34 @@ my %formatMinMax = (
     GROUPS => { 0 => 'MakerNotes', 2 => 'Image' },
     FIRST_ENTRY => 0,
     FORMAT => 'int32u',
-    NOTES => 'These tags tested only for DualShotVersion numbers 1, 4 and 5.',
-    0 => {
-        Name => 'DualShotVersion',
-        Format => 'int16u',
-        RawConv => '$$self{DualShotVersion} = $val',
-    },
-    9 => {
-        Name => 'DepthMapWidth',
-        Condition => '$$self{DualShotVersion} < 4',
-    },
-    10 => {
-        Name => 'DepthMapHeight',
-        Condition => '$$self{DualShotVersion} < 4',
+    # This is a pain, but the DepthMapWidth/Height move around in this record.
+    # In all of my samples so far, the bytes "01 00 ff ff" precede these tags.
+    # I have seen this byte sequence at offsets 32, 60, 64 and 68, so look for
+    # it in bytes 32-95, and use its location to adjust the tag positions
+    8 => {
+        Name => 'DualShotDummy',
+        Format => 'undef[64]',
+        Hidden => 1,
+        Hook => q{
+            if ($size >= 96) {
+                my $tmp = substr($$dataPt, $pos, 64);
+                if ($tmp =~ /\x01\0\xff\xff/g and not pos($tmp) % 4) {
+                    $$self{DepthMapTagPos} = pos($tmp);
+                    $varSize += $$self{DepthMapTagPos} - 32;
+                }
+            }
+        },
+        RawConv => 'undef', # not a real tag
     },
     16 => {
         Name => 'DepthMapWidth',
-        Condition => '$$self{DualShotVersion} == 4',
+        Condition => '$$self{DepthMapTagPos}',
+        Notes => 'index varies depending on model',
     },
     17 => {
         Name => 'DepthMapHeight',
-        Condition => '$$self{DualShotVersion} == 4',
-    },
-    18 => {
-        Name => 'DepthMapWidth',
-        Condition => '$$self{DualShotVersion} > 4',
-    },
-    19 => {
-        Name => 'DepthMapHeight',
-        Condition => '$$self{DualShotVersion} > 4',
+        Condition => '$$self{DepthMapTagPos}',
+        Notes => 'index varies depending on model',
     },
 );
 
@@ -1446,7 +1447,7 @@ Samsung maker notes in EXIF information.
 
 =head1 AUTHOR
 
-Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2020, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
